==> ejc-wzxt-impl-3.0.0-20211104.101405-113-sources.jar: com/ejianc/business/wzxt/bean/PlanDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_plan_detail")
public class PlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private Long planId; // 主表主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="nums")
    private BigDecimal nums; // 审批数量
    @TableField(value="plan_num")
    private BigDecimal planNum; // 需求数量
    @TableField(value="occupy_nums")
    private BigDecimal occupyNums; // 占用数量
    @TableField(value="surplus_nums")
    private BigDecimal surplusNums; // 剩余数量
    @TableField(value="memo")
    private String memo; // 备注

    private BigDecimal jhl; // PM计划量

    private BigDecimal planNumSum; // 累计计划量


    public BigDecimal getJhl() {
        return jhl;
    }

    public void setJhl(BigDecimal jhl) {
        this.jhl = jhl;
    }

    public BigDecimal getPlanNumSum() {
        return planNumSum;
    }

    public void setPlanNumSum(BigDecimal planNumSum) {
        this.planNumSum = planNumSum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-wzxt-impl-3.0.0-20211109.024402-120-sources.jar: com/ejianc/business/wzxt/bean/PlanDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_plan_detail")
public class PlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private Long planId; // 主表主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="nums")
    private BigDecimal nums; // 审批数量
    @TableField(value="plan_num")
    private BigDecimal planNum; // 需求数量
    @TableField(value="occupy_nums")
    private BigDecimal occupyNums; // 占用数量
    @TableField(value="surplus_nums")
    private BigDecimal surplusNums; // 剩余数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="is_excess")
    private Boolean isExcess; // 是否超量
    private BigDecimal jhl; // PM计划量

    private BigDecimal planNumSum; // 累计计划量

    public Boolean getExcess() {
        return isExcess;
    }

    public void setExcess(Boolean excess) {
        isExcess = excess;
    }

    public BigDecimal getJhl() {
        return jhl;
    }

    public void setJhl(BigDecimal jhl) {
        this.jhl = jhl;
    }

    public BigDecimal getPlanNumSum() {
        return planNumSum;
    }

    public void setPlanNumSum(BigDecimal planNumSum) {
        this.planNumSum = planNumSum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
